@@ -13,7 +13,7 @@ except ImportError:
         from haystack import site
         from haystack.exceptions import NotRegistered as IndexNotFoundException  # noqa
         legacy = True
-    except ImportError, e:
+    except ImportError as e:
         raise ImproperlyConfigured("Haystack couldn't be imported: %s" % e)
 
 if settings.CELERY_HAYSTACK_TRANSACTION_SAFE and not getattr(settings, 'CELERY_ALWAYS_EAGER', False):
@@ -67,7 +67,7 @@ class CeleryHaystackSignalHandler(Task):
         logger = self.get_logger(**kwargs)
         instance = None
         try:
-            instance = model_class._default_manager.get(pk=int(pk))
+            instance = model_class._default_manager.get(pk=pk)
         except model_class.DoesNotExist:
             logger.error("Couldn't load %s.%s.%s. Somehow it went missing?" %
                          (model_class._meta.app_label.lower(),
@@ -83,22 +83,16 @@ class CeleryHaystackSignalHandler(Task):
         try:
             if legacy:
                 index_holder = site
-                yield index_holder.get_index(model_class)
+                yield index_holder.get_index(model_class), self.using
             else:
                 using_backends = connection_router.for_write(**{'models': [model_class]})
                 for using in using_backends:
                     index_holder = connections[using].get_unified_index()
-                    yield index_holder.get_index(model_class)
+                    yield index_holder.get_index(model_class), using
         except IndexNotFoundException:
             raise ImproperlyConfigured("Couldn't find a SearchIndex for %s." %
                                        model_class)
 
-    def get_handler_options(self, **kwargs):
-        options = {}
-        if legacy:
-            options['using'] = self.using
-        return options
-
     def run(self, action, identifier, **kwargs):
         """
         Trigger the actual index handler depending on the
@@ -115,7 +109,7 @@ class CeleryHaystackSignalHandler(Task):
 
         # Then get the model class for the object path
         model_class = self.get_model_class(object_path, **kwargs)
-        for current_index in self.get_indexes(model_class, **kwargs):
+        for current_index, using in self.get_indexes(model_class, **kwargs):
             current_index_name = ".".join([current_index.__class__.__module__,
                                            current_index.__class__.__name__])
 
@@ -123,16 +117,14 @@ class CeleryHaystackSignalHandler(Task):
                 # If the object is gone, we'll use just the identifier
                 # against the index.
                 try:
-                    handler_options = self.get_handler_options(**kwargs)
-                    current_index.remove_object(identifier, **handler_options)
-                except Exception, exc:
+                    current_index.remove_object(identifier, using=using)
+                except Exception as exc:
                     logger.exception(exc)
                     self.retry(exc=exc)
                 else:
                     msg = ("Deleted '%s' (with %s)" %
                            (identifier, current_index_name))
                     logger.debug(msg)
-                    return msg
             elif action == 'update':
                 # and the instance of the model class with the pk
                 instance = self.get_instance(model_class, pk, **kwargs)
@@ -144,16 +136,14 @@ class CeleryHaystackSignalHandler(Task):
                 # Call the appropriate handler of the current index and
                 # handle exception if neccessary
                 try:
-                    handler_options = self.get_handler_options(**kwargs)
-                    current_index.update_object(instance, **handler_options)
-                except Exception, exc:
+                    current_index.update_object(instance, using=using)
+                except Exception as exc:
                     logger.exception(exc)
                     self.retry(exc=exc)
                 else:
                     msg = ("Updated '%s' (with %s)" %
                            (identifier, current_index_name))
                     logger.debug(msg)
-                    return msg
             else:
                 logger.error("Unrecognized action '%s'. Moving on..." % action)
                 raise ValueError("Unrecognized action %s" % action)
